;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "dslide" "20250102.819"
  "Domain Specific sLIDEs. Programmable Presentation."
  '((emacs "29.2"))
  :url "https://github.com/positron-solutions/dslide"
  :commit "be47f2dcb939779067f8c77c3493162bcf242b83"
  :revdesc "be47f2dcb939"
  :keywords '("convenience" "org-mode" "presentation" "narrowing")
  :authors '(("Positron" . "contact@positron.solutions"))
  :maintainers '(("Positron" . "contact@positron.solutions")))
